| bandnorm | R Documentation |
This function allows you to calculate the BandNorm normalization.
bandnorm(path = NULL, hic_df = NULL, save = TRUE, save_path = NULL)
path |
The path for all the cells in a directory. There can be sub-directories. |
hic_df |
If you prepare the dataset as a format of "chrom", "binA", "binB", "count", "diag", "cell", you can input it into bandnorm directly. |
save |
Whether to save each normalized cells. Default is TRUE. Note that if don't have large memory on your computer, and you need to use create_embedding function, it is highly recommended to save the cells because it helps lower the cost of memory in this function. |
save_path |
Indicate the output path for normalized cells. Only need it when "save" parameter is TRUE. Default is NULL. |
data("hic_df")
bandnorm_result = bandnorm(hic_df = hic_df, save = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.