| bandnorm_juicer | R Documentation |
This function allows you to calculate the BandNorm normalization using the inputs that are Juicer .hic format, and the output won't be different from the original version.
bandnorm_juicer(path = NULL, resolution, chroms, save = TRUE, save_path = NULL)
path |
The path for all the cells in a directory. There can be sub-directories. |
resolution |
Specify the resolution from the hic file." |
chroms |
Specify the chromosomes to use, the format is a string like "1". If the input is "all", it will include all the intra-chromosomal bin pairs. This does not allow inputting chrM and chrY currently. |
save |
Whether to save each normalized cells. Default is TRUE. Note that if don't have large memory on your computer, and you need to use create_embedding function, it is highly recommended to save the cells because it helps lower the cost of memory in this function. |
save_path |
Indicate the output path for normalized cells. Only need it when "save" parameter is TRUE. Default is NULL. |
# We will have a thorough example for this part!
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.