runProjection: Performing Projection for scGAD on other single-cell data

runProjectionR Documentation

Performing Projection for scGAD on other single-cell data

Description

This function allows you to project scGAD value on various assays.

Usage

runProjection(DataList, doNorm, cellTypeList)

Arguments

DataList

A list of matrices containing all assays. Each matrix should have a name that corresponds to the assay.

doNorm

A vector of boolean. Each entries determines whether each matrix should be normalized.

Examples

#

sshen82/BandNorm documentation built on June 1, 2025, 6:25 p.m.