| scGAD | R Documentation |
This function allows you to calculate GAD value for each gene in each cell.
scGAD(
path = NULL,
hic_df = NULL,
genes,
depthNorm = TRUE,
cores = 4,
threads = 8,
binPair = TRUE,
format = "short",
res = 10000
)
path |
A path to the single-cell Hi-C data. The data format should be the same as in the bandnorm hic_df input. |
hic_df |
You can also load dataframe containing all Hi-C data to here, but it is not recommended, since in scGAD, we are dealing with high resolution matrices, and it will consume a lot of memory if we load it directly. |
genes |
A data frame containing 5 columns: chrmomsome, start, end, strand, gene name. |
depthNorm |
Whether to normalize the sequencing depth effect. Default is TRUE. |
cores |
Number of cores used for parallel running. Default is 4. |
threads |
Number of threads for fread function, default is 8. |
binPair |
Use bin pair or valid reads. The former is faster since it is already binned, but the latter will be more accurate. Default is TRUE. |
format |
The format of the valid pairs. "short", "medium", "long", "4DN" are supported. See https://github.com/aidenlab/juicer/wiki/Pre. |
res |
The resolution of the data. Used only when binPair = TRUE. Default is 10000. |
#
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.