| runProjection | R Documentation |
This function allows you to project scGAD value on various assays.
runProjection(DataList, doNorm, cellTypeList)
DataList |
A list of matrices containing all assays. Each matrix should have a name that corresponds to the assay. |
doNorm |
A vector of boolean. Each entries determines whether each matrix should be normalized. |
#
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.